@@ -23,6 +23,7 @@ class Flight(object):
         self._trees  = {'fieldtree': None, 'dbtree': None, 'kvmaps': None}
         self._fields = []
         self.__cntr = 0
+        self._uri_root = conn._uri_root
 
         # Retreive the field tree data from local storage. If it doesn't exist, generate a new
         # default one.
@@ -75,13 +76,16 @@ class Flight(object):
 
 
     def __get_dbtree(self):
-        T = self._metadata.get_data("dbtree", "ems_id = %d" % self._ems_id)
+        T = self._metadata.get_data("dbtree", self.__get_filter('dbtree'))
         if len(T) < 1:
-            dbroot = {'ems_id': self._ems_id,
-                      'id': "[-hub-][entity-type-group][[--][internal-type-group][root]]",
-                      'name': "<root>",
-                      'nodetype': "root",
-                      'parent_id': None}
+            dbroot = {
+                'uri_root': self._uri_root,
+                'ems_id': self._ems_id,
+                'id': "[-hub-][entity-type-group][[--][internal-type-group][root]]",
+                'name': "<root>",
+                'nodetype': "root",
+                'parent_id': None
+            }
             self._trees['dbtree'] = pd.DataFrame([dbroot])
             self.__update_children(dbroot, treetype = "dbtree")
             self.update_tree("fdw", treetype = "dbtree", exclude_tree = ["APM Events"])
@@ -92,18 +96,18 @@ class Flight(object):
 
     def __save_dbtree(self):
         if len(self._trees['dbtree']) > 0:
-            self._metadata.delete_data("dbtree", "ems_id = %d" % self._ems_id)
+            self._metadata.delete_data("dbtree", self.__get_filter('dbtree'))
             self._metadata.append_data("dbtree", self._trees['dbtree'])
 
 
     def __get_kvmaps(self):
-        T = self._metadata.get_data("kvmaps", "ems_id = %d" % self._ems_id)
+        T = self._metadata.get_data("kvmaps", self.__get_filter('kvmaps'))
         return T
 
 
     def __save_kvmaps(self):
         if len(self._trees['kvmaps']) > 0:
-            self._metadata.delete_data("kvmaps", "ems_id = %d" % self._ems_id)
+            self._metadata.delete_data("kvmaps", self.__get_filter('kvmaps'))
             self._metadata.append_data("kvmaps", self._trees['kvmaps'])
 
 
@@ -135,18 +139,26 @@ class Flight(object):
                                        body=body)
         d1 = []
         if len(d['databases']) > 0:
-            d1 = [{'ems_id': parent['ems_id'],
-                                'id': x['id'],
-                                'nodetype': 'database',
-                                'name': x['pluralName'],
-                                'parent_id': parent['id']} for x in d['databases']]
+            d1 = [{'uri_root': parent['uri_root'] if 'uri_root' in parent.keys() else '',
+                   'ems_id': parent['ems_id'],
+                   'id': x['id'],
+                   'nodetype': 'database',
+                   'name': x['pluralName'],
+                   'parent_id': parent['id']} for x in d['databases']]
+            for _d in d1:
+                if _d['uri_root'] == '':
+                    _d.pop('uri_root')
         d2 = []
         if len(d['groups']) > 0:
-            d2 = [{'ems_id': parent['ems_id'],
-                                'id': x['id'],
-                                'nodetype': 'database_group',
-                                'name': x['name'],
-                                'parent_id': parent['id']} for x in d['groups']]
+            d2 = [{'uri_root': parent['uri_root'] if 'uri_root' in parent.keys() else '',
+                   'ems_id': parent['ems_id'],
+                   'id': x['id'],
+                   'nodetype': 'database_group',
+                   'name': x['name'],
+                   'parent_id': parent['id']} for x in d['groups']]
+            for _d in d2:
+                if _d['uri_root'] == '':
+                    _d.pop('uri_root')
         return d1, d2
 
 
@@ -159,22 +171,30 @@ class Flight(object):
                                        body=body)
         d1 = []
         if len(d['fields']) > 0:
-            d1 = [{'ems_id': parent['ems_id'],
-                                'db_id' : self._db_id,
-                                'id': x['id'],
-                                'nodetype': 'field',
-                                'type': x['type'],
-                                'name': x['name'],
-                                'parent_id': parent['id']} for x in d['fields']]
+            d1 = [{'uri_root': parent['uri_root'] if 'uri_root' in parent.keys() else '',
+                   'ems_id': parent['ems_id'],
+                   'db_id' : self._db_id,
+                   'id': x['id'],
+                   'nodetype': 'field',
+                   'type': x['type'],
+                   'name': x['name'],
+                   'parent_id': parent['id']} for x in d['fields']]
+            for _d in d1:
+                if _d['uri_root'] == '':
+                    _d.pop('uri_root')
         d2 = []
         if len(d['groups']) > 0:
-            d2 = [{'ems_id': parent['ems_id'],
-                                'db_id': self._db_id,
-                                'id': x['id'],
-                                'nodetype': 'field_group',
-                                'type': None,
-                                'name': x['name'],
-                                'parent_id': parent['id']} for x in d['groups']]
+            d2 = [{'uri_root': parent['uri_root'] if 'uri_root' in parent.keys() else '',
+                   'ems_id': parent['ems_id'],
+                   'db_id': self._db_id,
+                   'id': x['id'],
+                   'nodetype': 'field_group',
+                   'type': None,
+                   'name': x['name'],
+                   'parent_id': parent['id']} for x in d['groups']]
+            for _d in d2:
+                if _d['uri_root'] == '':
+                    _d.pop('uri_root')
         return d1, d2
 
 
@@ -410,10 +430,13 @@ class Flight(object):
             resp_h, content = self._conn.request(uri_keys=('database', 'field'),
                                                  uri_args=(self._ems_id, self._db_id, fld_id))
             km = content['discreteValues']
-            kmap = pd.DataFrame({'ems_id': self._ems_id,
-                                 'id': fld_id,
-                                 'key': list(km.keys()),
-                                 'value': list(km.values())})
+            kmap = pd.DataFrame({
+                'uri_root': self._uri_root,
+                'ems_id': self._ems_id,
+                'id': fld_id,
+                'key': list(km.keys()),
+                'value': list(km.values())
+            })
             kmap['key'] = pd.to_numeric(kmap['key'])
 
             self._trees['kvmaps'] = self._trees['kvmaps'].append(kmap, ignore_index=True)
@@ -440,6 +463,12 @@ class Flight(object):
             raise ValueError("%s could not be found from the list of the field values." % value)
         return int(key.values[0])
 
+    def __get_filter(self, tree):
+        filter = "ems_id = %d" % self._ems_id
+        if 'uri_root' in self._metadata.get_data(tree).columns:
+            filter += " AND uri_root = '%s'" % self._uri_root
+        return filter
+
 
 def get_shortest(fields):
     if isinstance(fields, pd.DataFrame) is False:
